@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = 0.22;
+our $VERSION = 0.2201;
 
 =head1 NAME
 
@@ -160,11 +160,12 @@ Otherwise it's ignored for security reasons.
 This is set by C<$request-E<gt>redirect(...)>.
 
 B<[DEPRECATED]> This will be phased out at some point,
-use C<-header => [ location =E<gt> ... ]> instead.
+use C<-header =E<gt> [ location =E<gt> ... ]> instead.
 
 =item * -serial - if present, the C<JS> view will render this instead of
 the whole response hash.
-This can be used e.g. to return non-hash data in REST API.
+This can be used, for instance, to return non-hash data in a REST API.
+
 B<[EXPERIMENTAL]> Name and meaning may change in the future.
 
 =item * -status - HTTP status (200, 404, 500 etc).
@@ -265,29 +266,30 @@ for given by URI path and HTTP method(s).
 
 =item * $neaf->route( '/path' => CODEREF, %options )
 
-=item * get '/path' => sub { ... }, %options
+=item * get '/path' => sub { CODE; }, %options;
 
 I<Equivalent> to
 
-    neaf->route( '/path' => sub { ... }, method => 'GET', %options )
+    neaf->route( '/path' => sub { CODE; }, method => 'GET', %options );
 
-=item * post ...
+=item * post '/path' => sub { CODE; }, %options;
 
-Ditto, but method => 'POST'
+Ditto, but sets method => 'POST'
 
-=item * head ... - autogenerated by C<get>
+=item * head ... - autogenerated by C<get>,
+but can be specified explicitly if needed
 
 =item * put ...
 
 =item * patch ...
 
-=item * del ... for C<DELETE>
+=item * del ... is for C<DELETE> (because C<delete> is a Perl's own keyword).
 
 =item * any [ 'get', 'post', 'CUSTOM_METHOD' ] => '/path' => \&handler
 
 =back
 
-Short aliases can be combined with the C<+> sign, as in
+Short aliases can be combined using the C<+> sign, as in
 
     get + post '/submit' => sub {
         my $req = shift;
@@ -355,11 +357,12 @@ See C<param()> in L<MVC::Neaf::Request>.
 B<[EXPERIMENTAL]> Name and semantics MAY change in the future.
 
 =item * C<view> - default View object for this Controller.
-Must be an object with a C<render> method, or a CODEREF
+Must be a name of preloaded view,
+an object with a C<render> method, or a CODEREF
 receiving hashref and returning a list of two scalars
 (content and content-type).
 
-B<[DEPRECATED]> Use -view instead, meaning is exactly the same.
+B<[DEPRECATED]> Use C<-view> instead, meaning is exactly the same.
 
 =item * C<cache_ttl> - if set, set Expires: HTTP header accordingly.
 
@@ -367,20 +370,19 @@ B<[EXPERIMENTAL]> Name and semantics MAY change in the future.
 
 =item * C<default> - a C<\%hash> of values that will be added to results
 EVERY time the handler returns.
-Consider using C<neaf default ...> below if you need to add
-the same values to multiple handlers.
+Consider using C<neaf default ...> below if you need to append
+the same values to multiple paths.
 
 =item * C<override> => 1 - replace old route even if it exists.
 If not set, route collisions causes exception.
 Use this if you know better.
 
-This still warns.
+This still issues a warning.
 
 B<[EXPERIMENTAL]> Name and meaning may change in the future.
 
-=item * C<tentative> => 1 - don't complain if this route is replaced.
-
-E.g. if setting a static stub for method to be added later.
+=item * C<tentative> => 1 - if route is already defined, do nothing.
+If not, allow to redefine it later.
 
 B<[EXPERIMENTAL]> Name and meaning may change in the future.
 
@@ -395,11 +397,11 @@ This is not enforced whatsoever.
 =back
 
 Also, any number of dash-prefixed keys MAY be present.
-This is totally the same as putting them into C<default> hash.
+This is the same as putting them into C<default> hash.
 
 B<[NOTE]> For some reason ability to add multicomponent paths
-like C<(foo => bar => \&code)> was added in the past,
-resulting in C<"/foo/bar" => \&code>.
+like C<(foo =E<gt> bar =E<gt> \&code)> was added in the past,
+resulting in C<"/foo/bar" =E<gt> \&code>.
 
 It was never documented, will issue a warning, and will be removed for good
 it v.0.25.
